# DÜDL
Welcome to DÜDL! Here's how to get started:

1. Download the files in this repository.
2. If you do not already have `pip` installed, download it [here](https://pip.pypa.io/en/stable/installation/) first, then run `pip install -e .` to install all dependencies. Alternatively, you may install all dependencies manually. 
3. Run with the `start-dudl` command, or just `python3 src/dudl_app.py`.

Once the server is running, note the IP address that is printed out (http://192.168.1.15:8001)